<?php

namespace Pizi\Recruit\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litepie\Repository\Filter\RequestFilter;
use Pizi\Recruit\Forms\JobApplication as JobApplicationForm;
use Pizi\Recruit\Http\Requests\JobApplicationRequest;
use Pizi\Recruit\Interfaces\JobApplicationRepositoryInterface;
use Pizi\Recruit\Repositories\Eloquent\Filters\JobApplicationResourceFilter;
use Pizi\Recruit\Repositories\Eloquent\Presenters\JobApplicationListPresenter;

/**
 * Resource controller class for job_application.
 */
class JobApplicationResourceController extends BaseController
{

    /**
     * Initialize job_application resource controller.
     *
     *
     * @return null
     */
    public function __construct(JobApplicationRepositoryInterface $job_application)
    {
        parent::__construct();
        $this->form = JobApplicationForm::setAttributes()->toArray();
        $this->modules = $this->modules(config('pizi.recruit.modules'), 'recruit', guard_url('recruit'));
        $this->repository = $job_application;
    }

    /**
     * Display a list of job_application.
     *
     * @return Response
     */
    public function index(JobApplicationRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(JobApplicationResourceFilter::class)
            ->setPresenter(JobApplicationListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('recruit::job_application.names'))
            ->view('recruit::job_application.index')
            ->data(compact('data', 'meta', 'links', 'modules', 'form'))
            ->output();
    }

    /**
     * Display job_application.
     *
     * @param Request $request
     * @param Model   $job_application
     *
     * @return Response
     */
    public function show(JobApplicationRequest $request, JobApplicationRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('recruit::job_application.name'))
            ->data(compact('data', 'form', 'modules', 'form'))
            ->view('recruit::job_application.show')
            ->output();
    }

    /**
     * Show the form for creating a new job_application.
     *
     * @param Request $request
     *x
     * @return Response
     */
    public function create(JobApplicationRequest $request, JobApplicationRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('recruit::job_application.name'))
            ->view('recruit::job_application.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Create new job_application.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(JobApplicationRequest $request, JobApplicationRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $attributes['user_type'] = user_type();
            $repository->create($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.created', ['Module' => trans('recruit::job_application.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('recruit/job_application/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/recruit/job_application'))
                ->redirect();
        }

    }

    /**
     * Show job_application for editing.
     *
     * @param Request $request
     * @param Model   $job_application
     *
     * @return Response
     */
    public function edit(JobApplicationRequest $request, JobApplicationRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('recruit::job_application.name'))
            ->view('recruit::job_application.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Update the job_application.
     *
     * @param Request $request
     * @param Model   $job_application
     *
     * @return Response
     */
    public function update(JobApplicationRequest $request, JobApplicationRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $repository->update($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('recruit::job_application.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('recruit/job_application/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('recruit/job_application/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the job_application.
     *
     * @param Model   $job_application
     *
     * @return Response
     */
    public function destroy(JobApplicationRequest $request, JobApplicationRepositoryInterface $repository)
    {
        try {
            $repository->delete();
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('recruit::job_application.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('recruit/job_application/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('recruit/job_application/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }
}
