<?php

namespace Pizi\Recruit\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Pizi\Recruit\Models\JobApplication;

class JobApplicationPolicy
{

    /**
     * Determine if the given user can view the job_application.
     *
     * @param UserPolicyInterface $authUser
     * @param JobApplication $job_application
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, JobApplication $job_application)
    {
        if ($authUser->canDo('recruit.job_application.view') && $authUser->isAdmin()) {
            return true;
        }

        return $job_application->user_id == user_id() && $job_application->user_type == user_type();
    }

    /**
     * Determine if the given user can create a job_application.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('recruit.job_application.create');
    }

    /**
     * Determine if the given user can update the given job_application.
     *
     * @param UserPolicyInterface $authUser
     * @param JobApplication $job_application
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, JobApplication $job_application)
    {
        if ($authUser->canDo('recruit.job_application.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $job_application->user_id == user_id() && $job_application->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given job_application.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, JobApplication $job_application)
    {
        return $job_application->user_id == user_id() && $job_application->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given job_application.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, JobApplication $job_application)
    {
        if ($authUser->canDo('recruit.job_application.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given job_application.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, JobApplication $job_application)
    {
        if ($authUser->canDo('recruit.job_application.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
